@@ -1,12 +1,10 @@
 # Licensed under the MIT License
-# https://github.com/craigahobbs/schema-markdown/blob/master/LICENSE
+# https://github.com/craigahobbs/schema-markdown/blob/main/LICENSE
 
 """
 Schema Markdown package imports
 """
 
-__version__ = '0.9.12'
-
 from .encode import \
     JSONEncoder, \
     decode_query_string, \
@@ -18,7 +16,12 @@ from .parser import \
 
 from .schema import \
     ValidationError, \
+    get_enum_values, \
     get_referenced_types, \
+    get_struct_members, \
     validate_type, \
     validate_type_model, \
     validate_type_model_types
+
+from .type_model import \
+    TYPE_MODEL
